@@ -1,8 +1,5 @@
-/* Copyright (c) 2002-2013 Pigeonhole authors, see the included COPYING file
- */
-
-#ifndef __SIEVE_EXT_ENOTIFY_H
-#define __SIEVE_EXT_ENOTIFY_H
+#ifndef SIEVE_EXT_ENOTIFY_H
+#define SIEVE_EXT_ENOTIFY_H
 
 #include "lib.h"
 #include "compat.h"
@@ -72,8 +69,10 @@ struct sieve_enotify_method_def {
 		(const struct sieve_enotify_print_env *penv,
 			const struct sieve_enotify_action *nact);
 
-	/* Action execution */
-	bool (*action_execute)
+	/* Action execution
+     (returns 0 if all is ok and -1 for temporary error)
+	 */
+	int (*action_execute)
 		(const struct sieve_enotify_exec_env *nenv,
 			const struct sieve_enotify_action *nact);
 };
@@ -122,6 +121,7 @@ void sieve_enotify_method_printf
 
 struct sieve_enotify_exec_env {
 	struct sieve_instance *svinst;
+	enum sieve_execute_flags flags;
 
 	const struct sieve_enotify_method *method;
 
@@ -158,6 +158,9 @@ struct sieve_enotify_action {
 #define sieve_enotify_info(ENV, ...) \
 	sieve_info((ENV)->ehandler, NULL, __VA_ARGS__ )
 
+#define sieve_enotify_critical(ENV, ...) \
+	sieve_critical((ENV)->svinst, (ENV)->ehandler, NULL, __VA_ARGS__ )
+
 #define sieve_enotify_global_error(ENV, ...) \
 	sieve_global_error((ENV)->svinst, (ENV)->ehandler, NULL, __VA_ARGS__ )
 
@@ -167,5 +170,8 @@ struct sieve_enotify_action {
 #define sieve_enotify_global_info(ENV, ...) \
 	sieve_global_info((ENV)->svinst, (ENV)->ehandler, NULL, __VA_ARGS__ )
 
-#endif /* __SIEVE_EXT_ENOTIFY_H */
+#define sieve_enotify_global_log_error(ENV, ...) \
+	sieve_global_info_error((ENV)->svinst, (ENV)->ehandler, NULL, __VA_ARGS__ )
+
+#endif
 
